import styles from "../../../styles";
import {
  Button,
  FormControl,
  InputLabel,
  MenuItem,
  Select,
  SelectChangeEvent,
} from "@mui/material";
import HourglassBottomIcon from "@mui/icons-material/HourglassBottom";
import CheckCircleIcon from "@mui/icons-material/CheckCircle";
import FlashOffIcon from "@mui/icons-material/FlashOff";
import { colors } from "../../../styles";
import Popup from "reactjs-popup";
import AddItemModal from "../../AddItemModal/AddItemModal";
import AddSKUModal from "../../AddSKUModal/AddSKUModal";
import CheckCircleOutlineIcon from "@mui/icons-material/CheckCircleOutline";
import ShoppingCartCheckoutIcon from "@mui/icons-material/ShoppingCartCheckout";
import AssignmentReturnedIcon from "@mui/icons-material/AssignmentReturned";
import CancelOutlinedIcon from "@mui/icons-material/CancelOutlined";
import CancelIcon from "@mui/icons-material/Cancel";
import ClearAllIcon from "@mui/icons-material/ClearAll";
import { useState } from "react";

type props = {
  filter: string;
  setFilter: React.Dispatch<React.SetStateAction<string>>;
};

export default function StudentTransactionFilterMenu(props: props) {
  const [addSKUmodalOpen, SetAddSKUModalOpen] = useState(false);
  const [additemmodalOpen, SetAddItemModalOpen] = useState(false);
  return (
    <>
      <p
        style={{
          ...styles.text_dark,
          ...styles.text_L,
        }}
      >
        Personal Transactions
      </p>

      <div
        style={{
          ...styles.flex_row,
          ...{
            alignSelf: "center",
            justifyContent: "center",
            flexWrap: "wrap",
          },
        }}
      >
        <FormControl sx={{ width: "384px" }}>
          <InputLabel style={{ backgroundColor: "white" }}>
            Filter Transactions
          </InputLabel>
          <Select
            value={props.filter}
            onChange={(e: SelectChangeEvent<string>) =>
              props.setFilter(e.target.value)
            }
          >
            <MenuItem value={""}>
              <Button
                style={{
                  ...styles.row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <ClearAllIcon
                  style={{
                    height: 32,
                    width: 32,
                    fill: colors.font_dark,
                    marginLeft: "1rem",
                    marginRight: "1rem",
                  }}
                />
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_M,
                  }}
                >
                  All
                </p>
              </Button>
            </MenuItem>
            <MenuItem value={"Pending Approval"}>
              <Button
                style={{
                  ...styles.row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <HourglassBottomIcon
                  style={{
                    height: 32,
                    width: 32,
                    fill: colors.font_dark,
                    marginLeft: "1rem",
                    marginRight: "1rem",
                  }}
                />
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_M,
                  }}
                >
                  Pending
                </p>
              </Button>
            </MenuItem>
            <MenuItem value={"Approved"}>
              <Button
                style={{
                  ...styles.flex_row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <CheckCircleOutlineIcon
                  style={{
                    height: 32,
                    width: 32,
                    fill: colors.font_dark,
                    marginLeft: "1rem",
                    marginRight: "1rem",
                  }}
                />
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_M,
                  }}
                >
                  Approved
                </p>
              </Button>
            </MenuItem>
            <MenuItem value={"Rejected"}>
              <Button
                style={{
                  ...styles.flex_row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <CancelOutlinedIcon
                  style={{
                    height: 32,
                    width: 32,
                    fill: colors.font_dark,
                    marginLeft: "1rem",
                    marginRight: "1rem",
                  }}
                />
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_M,
                  }}
                >
                  Rejected
                </p>
              </Button>
            </MenuItem>
            <MenuItem value={"Borrowed"}>
              <Button
                style={{
                  ...styles.flex_row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <ShoppingCartCheckoutIcon
                  style={{
                    height: 32,
                    width: 32,
                    fill: colors.font_dark,
                    marginLeft: "1rem",
                    marginRight: "1rem",
                  }}
                />
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_M,
                  }}
                >
                  On-Borrow
                </p>
              </Button>
            </MenuItem>
            <MenuItem value={"Cancelled"}>
              <Button
                style={{
                  ...styles.flex_row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <CancelIcon
                  style={{
                    height: 32,
                    width: 32,
                    fill: colors.font_dark,
                    marginLeft: "1rem",
                    marginRight: "1rem",
                  }}
                />
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_M,
                  }}
                >
                  Cancelled
                </p>
              </Button>
            </MenuItem>
            <MenuItem value={"Returned: Pending Checking"}>
              <Button
                style={{
                  ...styles.flex_row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <AssignmentReturnedIcon
                  style={{
                    height: 32,
                    width: 32,
                    fill: colors.font_dark,
                    marginLeft: "1rem",
                    marginRight: "1rem",
                  }}
                />
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_M,
                  }}
                >
                  Returned: Pending
                </p>
              </Button>
            </MenuItem>
            <MenuItem value={"Finalized"}>
              <Button
                style={{
                  ...styles.flex_row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <CheckCircleIcon
                  style={{
                    height: 32,
                    width: 32,
                    fill: colors.font_dark,
                    marginLeft: "1rem",
                    marginRight: "1rem",
                  }}
                />
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_M,
                  }}
                >
                  Finalized
                </p>
              </Button>
            </MenuItem>
            <MenuItem value={"With Breakages: Pending Resolution"}>
              <Button
                style={{
                  ...styles.flex_row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <FlashOffIcon
                  style={{
                    height: 32,
                    width: 32,
                    fill: colors.font_dark,
                    marginLeft: "1rem",
                    marginRight: "1rem",
                  }}
                />
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_M,
                  }}
                >
                  With Breakages
                </p>
              </Button>
            </MenuItem>
          </Select>
        </FormControl>
      </div>
      <div
        style={{
          ...styles.flex_row,
          ...{
            alignSelf: "center",
            justifyContent: "center",
            flexWrap: "wrap",
          },
        }}
      ></div>
      <Popup
        open={addSKUmodalOpen}
        onClose={() => SetAddSKUModalOpen(false)}
        modal
        position={"top center"}
        contentStyle={{
          width: "32rem",
          borderRadius: 16,
          borderColor: "grey",
          borderStyle: "solid",
          borderWidth: 1,
          padding: 16,
          alignContent: "center",
          justifyContent: "center",
          textAlign: "center",
        }}
      >
        <AddSKUModal />
      </Popup>
      <Popup
        open={additemmodalOpen}
        onClose={() => SetAddItemModalOpen(false)}
        modal
        position={"top center"}
        contentStyle={{
          width: "32rem",
          borderRadius: 16,
          borderColor: "grey",
          borderStyle: "solid",
          borderWidth: 1,
          padding: 16,
          alignContent: "center",
          justifyContent: "center",
          textAlign: "center",
        }}
      >
        <AddItemModal />
      </Popup>
    </>
  );
}
